@@ -2,7 +2,8 @@
 
 Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
     1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-    2006, 2007, 2008, 2009, 2010 Massachusetts Institute of Technology
+    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
+    2017, 2018, 2019 Massachusetts Institute of Technology
 
 This file is part of MIT/GNU Scheme.
 
@@ -78,8 +79,8 @@ USA.
          (rfc822:strip-quoted-names
           (rfc822:string->non-ignored-tokens string))))
     (if (and address-list
-             (for-all? (cdr address-list)
-               (lambda (token) (eqv? token #\,))))
+             (every (lambda (token) (eqv? token #\,))
+		    (cdr address-list)))
         (car address-list)
         (rfc822:split-address-tokens (rfc822:string->tokens string)))))
 
@@ -372,10 +373,10 @@ USA.
       tokens))
 
 (define (rfc822:strip-comments tokens)
-  (list-transform-negative tokens
-    (lambda (token)
-      (and (string? token)
-	   (char=? #\( (string-ref token 0))))))
+  (remove (lambda (token)
+	    (and (string? token)
+		 (char=? #\( (string-ref token 0))))
+	  tokens))
 
 ;;;; Tokenizer
 
@@ -386,8 +387,8 @@ USA.
   (let ((atom-chars
          (char-set-difference (ascii-range->char-set #x21 #x7F)
                               special-chars)))
-    (define (special-char? char) (char-set-member? special-chars char))
-    (define    (atom-char? char) (char-set-member?    atom-chars char))
+    (define (special-char? char) (char-in-set? char special-chars))
+    (define    (atom-char? char) (char-in-set?    char atom-chars))
 
     (define (lose chars char-count)
       (list (cons 'UNTERMINATED
@@ -556,7 +557,7 @@ USA.
 
 (define (reverse-list->string list start end)
   (let* ((length (fix:- end start))
-         (string (string-allocate length)))
+         (string (make-string length)))
     (let loop ((list (list-tail list start))
                (index length))
       (cond ((fix:zero? index)
