@@ -2,8 +2,8 @@
 
 Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
     1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Massachusetts
-    Institute of Technology
+    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
+    2017, 2018, 2019 Massachusetts Institute of Technology
 
 This file is part of MIT/GNU Scheme.
 
@@ -240,7 +240,7 @@ USA.
 
 #define TERM_MESSAGE_TABLE						\
 {									\
-/* 0x00 */		"Moriturus te saluto",				\
+/* 0x00 */		0,						\
 /* 0x01 */		"Unrecoverable error while loading a band",	\
 /* 0x02 */		"Broken heart encountered",			\
 /* 0x03 */		"Non pointer relocation",			\
@@ -268,5 +268,17 @@ USA.
 /* 0x19 */		"User requested termination after trap",	\
 /* 0x1A */		"Backing out of non-primitive"			\
 }
+
+#define MAX_HALT_MESSAGE	7
 
+#define TERM_HALT_MESSAGE_TABLE						\
+{									\
+    "Moriturus te saluto.",						\
+    "Happy happy joy joy!",						\
+    "Ceterum censeo Carthaginem esse delendam.",			\
+    "..#]^@^@^@ NO CARRIER",						\
+    "Fortitudine vincimus.",						\
+    "Post proelium, praemium.",						\
+    "Pulvis et umbra sumus."						\
+}
 #endif /* SCM_ERRORS_H */
